@@ -1,5 +1,4 @@
-from requests.exceptions import HTTPError
-from requests.exceptions import ConnectionError
+from requests.exceptions import HTTPError, ConnectionError, JSONDecodeError
 
 import json
 import logging
@@ -11,7 +10,7 @@ class KafkaConnect():
     Args:
         endpoint (str): The base URL for the Kafka Connect REST API.
         auth (str): A colon-delimited string of `username` and `password` to use for authenticating with the Kafka Connect REST API.
-        verify (bool): Whether to verify the SSL certificate when making requests to the Kafka Connect REST API. Defaults to False.
+        ssl_verify (bool): Whether to verify the SSL certificate when making requests to the Kafka Connect REST API. Defaults to True.
         logger (logging.Logger): The logger to be used. If not specified, a new logger will be created.
     """
     def __init__(self, endpoint="http://localhost:8083", auth=None, ssl_verify=True, logger=None):
@@ -35,7 +34,7 @@ class KafkaConnect():
 
         self.logger = logger if logger else logging.getLogger()
 
-    def get_info(self):
+    def get_cluster_info(self):
         """Get the version and other details of the Kafka Connect cluster.
         Returns:
             Dict[str, str]: The details of the cluster, including its version, commit ID, and Kafka cluster ID.
@@ -79,7 +78,7 @@ class KafkaConnect():
         Args:
             config (Dict[str, Any]): The configuration for the connector.
         Returns:
-            Dict[str, Any]: The response from the REST API, if any.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         Raises:
             HTTPError: If the REST API responds with a non-200 status code.
         """
@@ -88,11 +87,14 @@ class KafkaConnect():
         response = requests.post(url, auth=self.auth, verify=self.verify, headers=self.headers, data=json.dumps(config))
         
         if response.status_code == 409:
-            # A rebalance is needed, forthcoming, or underway.
             self.logger.error("Connector already exists or rebalance is in process.")
         
         response.raise_for_status()
-        return response.json()
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def update_connector(self, connector, config):
         """Update an existing connector.
@@ -100,7 +102,7 @@ class KafkaConnect():
             connector (str): The name of the connector.
             config (Dict[str, Any]): The new configuration for the connector.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
     
         if "config" in config:
@@ -111,13 +113,16 @@ class KafkaConnect():
         response = requests.put(url, headers=self.headers, auth=self.auth, verify=self.verify, data=json.dumps(config))
 
         if response.status_code == 409:
-            # A rebalance is underway.
             self.logger.error("Connector rebalance is in process.")
         else:
             return response.json()
 
         response.raise_for_status()
-        return response
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def get_connector_config(self, connector):
         """Get the configuration of a single connector.
@@ -153,79 +158,89 @@ class KafkaConnect():
                 Defaults to `False`.
             only_failed (bool): Whether to restart only failed Task objects. Defaults to `False`.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Restarting connector: {connector}")
         url = f"{self.endpoint}/connectors/{connector}/restart"
         params = {"includeTasks": include_tasks, "onlyFailed": only_failed}
         response = requests.post(url, auth=self.auth, verify=self.verify, params=params)
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
         
         if response.status_code == 200:
-            # The connector was successfully restarted.
             self.logger.info("Connector restarted successfully.")
-            return
+            return data
         elif response.status_code == 202:
-            # The connector restart request was accepted and is being processed.
             self.logger.info("Connector restart request accepted.")
-            return response.json()
+            return data
         elif response.status_code == 204:
-            # The operation was successful but there is no content in the response.
             self.logger.info("Connector restart request successful, but no response body returned.")
-            return
+            return data
         elif response.status_code == 404:
-            # The named connector does not exist.
             self.logger.error("Connector not found.")
             raise HTTPError(response.text)
         elif response.status_code == 409:
-            # A rebalance is needed, forthcoming, or underway.
             self.logger.error("Rebalance needed to restart connector.")
             raise HTTPError(response.text)
         elif response.status_code == 500:
-            # The request timed out.
             self.logger.error("Connector restart request timed out.")
             raise HTTPError(response.text)
         
         response.raise_for_status()
-        return response
+        return data
 
     def pause_connector(self, connector):
         """Pause a single connector.
         Args:
             connector (str): The name of the connector.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Pausing connector: {connector}")
         url = f"{self.endpoint}/connectors/{connector}/pause"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
-        return response.json()
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def resume_connector(self, connector):
         """Resume a single connector.
         Args:
             connector (str): The name of the connector.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Resuming connector: {connector}")
         url = f"{self.endpoint}/connectors/{connector}/resume"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
-        return response.json()
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def delete_connector(self, connector):
         """Delete a single connector.
         Args:
             connector (str): The name of the connector.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Deleting connector: {connector}")
         url = f"{self.endpoint}/connectors/{connector}"
         response = requests.delete(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
-        return response.json()
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def list_connector_tasks(self, connector):
         """Get the list of tasks for a connector.
@@ -260,13 +275,17 @@ class KafkaConnect():
             connector (str): The name of the connector.
             task_id (int): The ID of the task.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Restarting task {task_id} of connector: {connector}")
         url = f"{self.endpoint}/connectors/{connector}/tasks/{task_id}/restart"
         response = requests.post(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
-        return response.json()
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def list_connector_topics(self, connector):
         """Get the list of topics for a connector.
@@ -286,13 +305,17 @@ class KafkaConnect():
         Args:
             connector (str): The name of the connector.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Resetting topics for connector: {connector}")
         url = f"{self.endpoint}/connectors/{connector}/topics/reset"
         response = requests.put(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
-        return response.json()
+        try:
+            return response.json()
+        except JSONDecodeError:
+            data = None
+        return data
 
     def list_connector_plugins(self):
         """Get the list of connector plugins.
@@ -312,10 +335,14 @@ class KafkaConnect():
             plugin (str): The name of the plugin.
             config (Dict[str, Any]): The configuration to be validated.
         Returns:
-            Dict[str, Any]: The response from the REST API.
+            Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
         self.logger.info(f"Validating config for plugin: {plugin}")
         url = f"{self.endpoint}/connector-plugins/{plugin}/config/validate"
         response = requests.put(url, auth=self.auth, verify=self.verify, headers=self.headers, data=json.dumps(config))
         response.raise_for_status()
-        return response.json()
+        try:
+            data = response.json()
+        except JSONDecodeError:
+            data = None
+        return data
